summaryrefslogtreecommitdiffhomepage
path: root/src/nxt_timer.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/nxt_timer.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/nxt_timer.h b/src/nxt_timer.h
index 211564d6..4199f0dd 100644
--- a/src/nxt_timer.h
+++ b/src/nxt_timer.h
@@ -8,9 +8,9 @@
#define _NXT_TIMER_H_INCLUDED_
/* Valid values are between 1ms to 255ms. */
#define NXT_TIMER_DEFAULT_PRECISION 100
//#define NXT_TIMER_DEFAULT_PRECISION 1
/*
@@ -25,7 +25,7 @@ typedef struct {
/* The rbtree node must be the first field. */
NXT_RBTREE_NODE (node);
- uint8_t precision;
+ uint8_t bias;
uint16_t change:14;
uint16_t enabled:1;
@@ -8,9 +8,9 @@
#define _NXT_TIMER_H_INCLUDED_
-/* Valid values are between 1ms to 255ms. */
-#define NXT_TIMER_DEFAULT_PRECISION 100
-//#define NXT_TIMER_DEFAULT_PRECISION 1
+/* Valid values are between 0ms to 255ms. */
+#define NXT_TIMER_DEFAULT_BIAS 50
+//#define NXT_TIMER_DEFAULT_BIAS 0
/*